sequencetools.iterate_sequence_forward_and_backward_nonoverlapping
==================================================================

.. autofunction:: abjad.tools.sequencetools.iterate_sequence_forward_and_backward_nonoverlapping.iterate_sequence_forward_and_backward_nonoverlapping
